@@ -17,13 +17,16 @@
 //
 // Copyright (C) 2006 Kristian Høgsberg <krh@redhat.com>
 // Copyright (C) 2006 Krzysztof Kowalczyk <kkowalczyk@gmail.com>
-// Copyright (C) 2008-2010, 2012, 2014, 2017, 2018 Albert Astals Cid <aacid@kde.org>
+// Copyright (C) 2008-2010, 2012, 2014, 2017-2020 Albert Astals Cid <aacid@kde.org>
 // Copyright (C) 2012-2014 Fabio D'Urso <fabiodurso@hotmail.it>
 // Copyright (C) 2013 Jason Crain <jason@aquaticape.us>
 // Copyright (C) 2015, 2018 Adam Reichold <adam.reichold@t-online.de>
 // Copyright (C) 2016 Jakub Alba <jakubalba@gmail.com>
 // Copyright (C) 2017 Adrian Johnson <ajohnson@redneon.com>
 // Copyright (C) 2018 Klarälvdalens Datakonsult AB, a KDAB Group company, <info@kdab.com>. Work sponsored by the LiMux project of the city of Munich
+// Copyright (C) 2019 Christophe Fergeau <cfergeau@redhat.com>
+// Copyright (C) 2019 Tomoyuki Kubota <himajin100000@gmail.com>
+// Copyright (C) 2019, 2020 Oliver Sander <oliver.sander@tu-dresden.de>
 //
 // To see a description of the changes please see the Changelog file that
 // came with your tarball or type make ChangeLog if you are building from git
@@ -65,6 +68,7 @@ public:
   explicit GooString(std::string&& str) : std::string(std::move(str)) {}
 
   const std::string& toStr() const { return *this; }
+  std::string& toNonConstStr() { return *this; }
 
   // Create a string from <lengthA> chars at <sA>.  This string
   // can contain null characters.
@@ -89,9 +93,6 @@ public:
     static_cast<std::string&>(*this).append(*str2);
   }
 
-  // Convert an integer to a string.
-  static GooString *fromInt(int x);
-
   // Create a formatted string.  Similar to printf, but without the
   // string overflow issues.  Formatting elements consist of:
   //     {<arg>:[<width>][.<precision>]<type>}
@@ -140,6 +141,7 @@ public:
   // Append a character or string.
   GooString *append(char c) { push_back(c); return this; }
   GooString *append(const GooString *str) { static_cast<std::string&>(*this).append(*str); return this; }
+  GooString *append(const std::string& str) { static_cast<std::string&>(*this).append(str); return this; }
   GooString *append(const char *str) { static_cast<std::string&>(*this).append(str); return this; }
   GooString *append(const char *str, int lengthA) { static_cast<std::string&>(*this).append(str, lengthA); return this; }
 
@@ -156,12 +158,12 @@ public:
   // Delete a character or range of characters.
   GooString *del(int i, int n = 1) { erase(i, n); return this; }
 
-  // Convert string to all-upper/all-lower case.
-  GooString *upperCase();
+  // Convert string to all-lower case.
   GooString *lowerCase();
 
   // Compare two strings:  -1:<  0:=  +1:>
   int cmp(const GooString *str) const { return compare(*str); }
+  int cmp(const std::string &str) const { return compare(str); }
   int cmpN(GooString *str, int n) const { return compare(0, n, *str); }
   int cmp(const char *sA) const { return compare(sA); }
   int cmpN(const char *sA, int n) const { return compare(0, n, sA); }
@@ -171,7 +173,10 @@ public:
   // Return true if string ends with suffix
   bool endsWith(const char *suffix) const;
 
-  bool hasUnicodeMarker() const { return size() >= 2 && (*this)[0] == char(0xfe) && (*this)[1] == char(0xff); }
+  bool hasUnicodeMarker() const { return hasUnicodeMarker(*this); }
+  static bool hasUnicodeMarker(const std::string& s) { return s.size() >= 2 && s[0] == '\xfe' && s[1] == '\xff'; }
+  bool hasUnicodeMarkerLE() const { return hasUnicodeMarkerLE(*this); }
+  static bool hasUnicodeMarkerLE(const std::string& s) { return s.size() >= 2 && s[0] == '\xff' && s[1] == '\xfe'; }
   bool hasJustUnicodeMarker() const { return size() == 2 && hasUnicodeMarker(); }
 
   void prependUnicodeMarker();
